Learn R Programming

Thermimage (version 2.0)

Grasshof: Determines the Grasshof number for an object

Description

Determines the Grasshof number for an object. The Grasshof number is used in calculations of heat exchange.

Usage

Grasshof(L = 1, Ts = 20, Ta = 20)

Arguments

L
Characteristic dimension of object in metres. Usually height, depending on object shape.
Ts
Surface Temperature of object, in degrees Celsius.
Ta
Air/Ambient Temperature surrounding object, in degrees Celsius.

Details

Gr=agL^3(Ts-Ta)/v^2 L is the characteristic dimension, usually the vertical dimension. For reference, a cylinder's characteristic L would be its height, assuming it is standing on its end Units of L should be in metres This L should be the same L as is used for the convective coefficient calculation Ts is the surface temperature Ta is the ambient temperature v2 is the kinematic viscosity squared (calculated from airviscosity(Ta))

References

Source: Blaxter, K. 1989. Energy Metabolism in Animals and Man.

See Also

airviscosity

Examples

Run this code
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
function (L = 1, Ts = 20, Ta = 20, v = airviscosity(20)) 
{
    a <- 1/273
    g <- 9.81
    Gr <- a * g * L^3 * (Ts - Ta)/v^2
    Gr
  }

Run the code above in your browser using DataLab